==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/es.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'es', {
	button: {
		title: 'Propiedades de Botón',
		text: 'Texto (Valor)',
		type: 'Tipo',
		typeBtn: 'Boton',
		typeSbm: 'Enviar',
		typeRst: 'Reestablecer'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Propiedades de Casilla',
		radioTitle: 'Propiedades de Botón de Radio',
		value: 'Valor',
		selected: 'Seleccionado',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Propiedades de Formulario',
		menu: 'Propiedades de Formulario',
		action: 'Acción',
		method: 'Método',
		encoding: 'Codificación'
	},
	hidden: {
		title: 'Propiedades de Campo Oculto',
		name: 'Nombre',
		value: 'Valor'
	},
	select: {
		title: 'Propiedades de Campo de Selección',
		selectInfo: 'Información',
		opAvail: 'Opciones disponibles',
		value: 'Valor',
		size: 'Tamaño',
		lines: 'Lineas',
		chkMulti: 'Permitir múltiple selección',
		required: 'Required', // MISSING
		opText: 'Texto',
		opValue: 'Valor',
		btnAdd: 'Agregar',
		btnModify: 'Modificar',
		btnUp: 'Subir',
		btnDown: 'Bajar',
		btnSetValue: 'Establecer como predeterminado',
		btnDelete: 'Eliminar'
	},
	textarea: {
		title: 'Propiedades de Area de Texto',
		cols: 'Columnas',
		rows: 'Filas'
	},
	textfield: {
		title: 'Propiedades de Campo de Texto',
		name: 'Nombre',
		value: 'Valor',
		charWidth: 'Caracteres de ancho',
		maxChars: 'Máximo caracteres',
		required: 'Required', // MISSING
		type: 'Tipo',
		typeText: 'Texto',
		typePass: 'Contraseña',
		typeEmail: 'Correo electrónico',
		typeSearch: 'Buscar',
		typeTel: 'Número de teléfono',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/forms/lang/es.js <==
/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'forms', 'es', {
	button: {
		title: 'Propiedades de Botón',
		text: 'Texto (Valor)',
		type: 'Tipo',
		typeBtn: 'Boton',
		typeSbm: 'Enviar',
		typeRst: 'Reestablecer'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Propiedades de Casilla',
		radioTitle: 'Propiedades de Botón de Radio',
		value: 'Valor',
		selected: 'Seleccionado',
		required: 'Requerido'
	},
	form: {
		title: 'Propiedades de Formulario',
		menu: 'Propiedades de Formulario',
		action: 'Acción',
		method: 'Método',
		encoding: 'Codificación'
	},
	hidden: {
		title: 'Propiedades de Campo Oculto',
		name: 'Nombre',
		value: 'Valor'
	},
	select: {
		title: 'Propiedades de Campo de Selección',
		selectInfo: 'Información',
		opAvail: 'Opciones disponibles',
		value: 'Valor',
		size: 'Tamaño',
		lines: 'Lineas',
		chkMulti: 'Permitir múltiple selección',
		required: 'Requerido',
		opText: 'Texto',
		opValue: 'Valor',
		btnAdd: 'Agregar',
		btnModify: 'Modificar',
		btnUp: 'Subir',
		btnDown: 'Bajar',
		btnSetValue: 'Establecer como predeterminado',
		btnDelete: 'Eliminar'
	},
	textarea: {
		title: 'Propiedades de Area de Texto',
		cols: 'Columnas',
		rows: 'Filas'
	},
	textfield: {
		title: 'Propiedades de Campo de Texto',
		name: 'Nombre',
		value: 'Valor',
		charWidth: 'Caracteres de ancho',
		maxChars: 'Máximo caracteres',
		required: 'Requerido',
		type: 'Tipo',
		typeText: 'Texto',
		typePass: 'Contraseña',
		typeEmail: 'Correo electrónico',
		typeSearch: 'Buscar',
		typeTel: 'Número de teléfono',
		typeUrl: 'URL'
	}
} );
